@@ -466,6 +466,9 @@ namespace giac {
   extern const unary_function_ptr * const  at_qr ;
   matrice thrownulllines(const matrice & res);
 
+  extern const unary_function_ptr * const  at_lll_reduce ;
+  extern const unary_function_ptr * const  at_lll ;
+
   gen _cholesky(const gen & a,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_cholesky ;
   gen _svd(const gen & a,GIAC_CONTEXT);
@@ -491,6 +494,7 @@ namespace giac {
 
   void matrice2std_matrix_gen(const matrice & m,std_matrix<gen> & M);
   void std_matrix_gen2matrice(const std_matrix<gen> & M,matrice & m);
+  void std_matrix_gen2matrice_destroy(std_matrix<gen> & M,matrice & m);
 
   bool is_integer_vecteur(const vecteur & m,bool intonly=false);
   bool is_integer_matrice(const matrice & m,bool intonly=false);
